@@ -1,4 +1,4 @@
-from maleo.schemas.resource import Resource, ResourceIdentifier
+from nexo.schemas.resource import Resource, ResourceIdentifier
 
 RULE_RESOURCE = Resource(
     identifiers=[ResourceIdentifier(key="rule", name="Rule", slug="rules")],
