@@ -25,6 +25,16 @@ class IdentifierType(StrEnum):
         return self.value
 
 
+class Process(StrEnum):
+    START = "start"
+    REVIEW = "review"
+    APPROVE = "approve"
+
+    @classmethod
+    def choices(cls) -> ListOfStrs:
+        return [e.value for e in cls]
+
+
 class CheckupStatus(StrEnum):
     DRAFT = "draft"
     ONGOING = "ongoing"
@@ -43,3 +53,15 @@ OptListOfCheckupStatuses = ListOfCheckupStatuses | None
 OptListOfCheckupStatusesT = TypeVar(
     "OptListOfCheckupStatusesT", bound=OptListOfCheckupStatuses
 )
+
+
+class Feedback(StrEnum):
+    POSITIVE = "positive"
+    NEGATIVE = "negative"
+
+    @classmethod
+    def choices(cls) -> ListOfStrs:
+        return [e.value for e in cls]
+
+
+OptFeedback = Feedback | None
