@@ -1,9 +1,9 @@
 from pydantic import BaseModel, Field
 from typing import Annotated, Generic, Literal, TypeGuard
 from uuid import UUID
-from maleo.schemas.mixins.identity import Identifier, Name as BaseName
-from maleo.types.boolean import OptBoolT
-from maleo.types.string import OptStrT, OptListOfStrs, OptListOfStrsT
+from nexo.schemas.mixins.identity import Identifier, Name as BaseName
+from nexo.types.boolean import OptBoolT
+from nexo.types.string import OptStrT, OptListOfStrs, OptListOfStrsT
 from ..enums.parameter import (
     IdentifierType,
     OptParameterGroupT,
