@@ -61,16 +61,18 @@ class BorderlineLow(BaseModel):
     ] = None
 
 
-class NormalMin(BaseModel):
-    normal_min: Annotated[OptFloat, Field(None, description="Normal Min", ge=0.0)] = (
-        None
-    )
+NormalMinT = TypeVar("NormalMinT", bound=OptFloat)
 
 
-class NormalMax(BaseModel):
-    normal_max: Annotated[OptFloat, Field(None, description="Normal Max", ge=0.0)] = (
-        None
-    )
+class NormalMin(BaseModel, Generic[NormalMinT]):
+    normal_min: Annotated[NormalMinT, Field(..., description="Normal Min", ge=0.0)]
+
+
+NormalMaxT = TypeVar("NormalMaxT", bound=OptFloat)
+
+
+class NormalMax(BaseModel, Generic[NormalMaxT]):
+    normal_max: Annotated[NormalMaxT, Field(..., description="Normal Max", ge=0.0)]
 
 
 class BorderlineHigh(BaseModel):
@@ -105,8 +107,8 @@ class RuleData(
     BorderlineReactive,
     CriticalHigh,
     BorderlineHigh,
-    NormalMax,
-    NormalMin,
+    NormalMax[float],
+    NormalMin[float],
     BorderlineLow,
     CriticalLow,
     AgeRangeMixin[AgeRange],
