@@ -21,10 +21,13 @@ from nexo.schemas.mixins.identity import (
     DateOfBirth,
 )
 from nexo.schemas.mixins.timestamp import LifecycleTimestamp
+from nexo.types.integer import OptInt
 from nexo.types.string import OptStr, OptListOfStrs
 from nexo.types.uuid import ListOfUUIDs
 from ..enums.checkup import CheckupStatus as CheckupStatusEnum
 from ..enums.examination import OptExaminationStatus
+from ..enums.finding_parameter import Criteria as CriteriaEnum
+from ..enums.finding import Logic as LogicEnum
 from ..enums.parameter import (
     ParameterGroup,
     ValueType as ValueTypeEnum,
@@ -34,6 +37,13 @@ from ..mixins.common import ParameterIds
 from ..mixins.checkup import CheckupStatus, RadiologyRecordId
 from ..mixins.client import Name as ClientName
 from ..mixins.examination import ExaminationStatus, Value, Unit as ExaminationUnit
+from ..mixins.finding_parameter import Criteria, Weight
+from ..mixins.finding import (
+    Name as FindingName,
+    Aliases as FindingAliases,
+    Recommendation,
+    Logic,
+)
 from ..mixins.parameter import (
     _validate_value_type_and_options,
     Group,
@@ -177,6 +187,68 @@ class RuleSchemaMixin(BaseModel, Generic[OptAnyRuleSchemaT]):
     rule: Annotated[OptAnyRuleSchemaT, Field(..., description="Rule")]
 
 
+class StandardFindingSchema(
+    Logic[LogicEnum],
+    Recommendation[str],
+    FindingAliases[OptListOfStrs],
+    FindingName[str],
+    SimpleDataStatusMixin[DataStatus],
+    LifecycleTimestamp,
+    DataIdentifier,
+):
+    pass
+
+
+ListOfStandardFindingSchemas = list[StandardFindingSchema]
+
+
+class FindingParameterSchema(
+    Weight[OptInt],
+    Criteria[CriteriaEnum],
+    StandardParameterSchemaMixin,
+    SimpleDataStatusMixin[DataStatus],
+    LifecycleTimestamp,
+    DataIdentifier,
+):
+    pass
+
+
+ListOfFindingParameterSchemas = list[FindingParameterSchema]
+
+
+class FindingParameterSchemasMixin(BaseModel):
+    parameters: Annotated[
+        ListOfFindingParameterSchemas,
+        Field(ListOfFindingParameterSchemas(), description="Finding Parameters"),
+    ] = ListOfFindingParameterSchemas()
+
+
+class FullFindingSchema(
+    FindingParameterSchemasMixin,
+    StandardFindingSchema,
+):
+    pass
+
+
+ListOfFullFindingSchemas = list[FullFindingSchema]
+
+
+AnyFindingSchemaType = Type[StandardFindingSchema] | Type[FullFindingSchema]
+AnyFindingSchema = StandardFindingSchema | FullFindingSchema
+AnyFindingSchemaT = TypeVar("AnyFindingSchemaT", bound=AnyFindingSchema)
+OptAnyFindingSchema = AnyFindingSchema | None
+OptAnyFindingSchemaT = TypeVar("OptAnyFindingSchemaT", bound=OptAnyFindingSchema)
+
+
+class LabExtractedExaminationData(BaseModel):
+    parameter: Annotated[str, Field(..., description="Parameter's name")]
+    value: Annotated[str, Field(..., description="Parameter's value")]
+    unit: Annotated[str, Field(..., description="Parameter's unit")]
+
+
+ListOfLabExtractedExaminationData = list[LabExtractedExaminationData]
+
+
 class RawExaminationSchema(
     ExaminationUnit,
     Value,
