@@ -6,11 +6,11 @@ from io import StringIO
 from fastapi import UploadFile
 from pydantic import BaseModel, Field, PrivateAttr, model_validator
 from typing import Annotated, Generic, Self, TypeVar, TypedDict
-from maleo.enums.identity import Gender
-from maleo.schemas.error.enums import ErrorCode
-from maleo.types.dict import ListOfStrToStrDict
-from maleo.types.integer import OptInt
-from maleo.types.string import OptStr, SeqOfStrs
+from nexo.enums.identity import Gender
+from nexo.schemas.error.enums import ErrorCode
+from nexo.types.dict import ListOfStrToStrDict
+from nexo.types.integer import OptInt
+from nexo.types.string import OptStr, SeqOfStrs
 from ..enums.parameter import ParameterGroup
 
 
@@ -105,6 +105,17 @@ class CSVDocument(Document):
         self._validate_content_type()
         return self
 
+    @classmethod
+    def from_document(cls, document: Document) -> Self:
+        csv_document = cls(
+            content=document.content,
+            content_type=document.content_type,
+            filename=document.filename,
+            size=document.size,
+        )
+        csv_document._raw = document._raw
+        return csv_document
+
     @classmethod
     async def from_file(
         cls,
@@ -391,6 +402,17 @@ class PDFDocument(Document):
         self._validate_content_type()
         return self
 
+    @classmethod
+    def from_document(cls, document: Document) -> Self:
+        pdf_document = cls(
+            content=document.content,
+            content_type=document.content_type,
+            filename=document.filename,
+            size=document.size,
+        )
+        pdf_document._raw = document._raw
+        return pdf_document
+
     @classmethod
     async def from_file(
         cls,
@@ -408,6 +430,9 @@ class PDFDocument(Document):
         )
 
 
+OptPDFDocument = PDFDocument | None
+
+
 AnyDocument = Document | CSVDocument | GroupCSVDocument | PDFDocument
 AnyDocumentT = TypeVar("AnyDocumentT", bound=AnyDocument)
 OptAnyDocument = AnyDocument | None
@@ -441,7 +466,7 @@ class OptHomogenousDocumentsMixin(BaseModel, Generic[AnyDocumentT]):
 
 
 class DocumentName(BaseModel):
-    document_name: Annotated[str, Field(..., description="Document's name")]
+    document_name: Annotated[OptStr, Field(None, description="Document's name")] = None
 
 
 class DocumentURL(BaseModel):
