@@ -4,7 +4,7 @@ from ..schemas.common import (
     FullSessionSchema,
     AnySessionSchemaType,
 )
-from ..enums.checkup import Granularity
+from ..enums.session import Granularity
 
 
 @overload
